@@ -1,12 +1,12 @@
 package SPOPS::Configure::DBI;
 
-# $Header: /usr/local/cvsdocs/SPOPS/SPOPS/Configure/DBI.pm,v 1.26 2000/10/16 16:33:06 cwinters Exp $
+# $Header: /usr/local/cvsdocs/SPOPS/SPOPS/Configure/DBI.pm,v 1.29 2000/10/27 04:05:45 cwinters Exp $
 
 use strict;
 use SPOPS::Configure;
 
 @SPOPS::Configure::DBI::ISA     = qw( SPOPS::Configure );
-$SPOPS::Configure::DBI::VERSION = sprintf("%d.%02d", q$Revision: 1.26 $ =~ /(\d+)\.(\d+)/);
+$SPOPS::Configure::DBI::VERSION = sprintf("%d.%02d", q$Revision: 1.29 $ =~ /(\d+)\.(\d+)/);
 
 use constant DEBUG => 0;
 
@@ -158,6 +158,8 @@ sub create_relationship {
 
 1;
 
+__END__
+
 =pod
 
 =head1 NAME
@@ -270,6 +272,7 @@ it under the same terms as Perl itself.
 
 =head1 AUTHORS
 
- Chris Winters (cwinters@intes.net)
+Chris Winters  <cwinters@intes.net>
+
 
 =cut
