@@ -1,11 +1,11 @@
 package SPOPS::DBI::Sybase;
 
-# $Header: /usr/local/cvsdocs/SPOPS/SPOPS/DBI/Sybase.pm,v 1.10 2000/10/09 15:07:50 cwinters Exp $
+# $Header: /usr/local/cvsdocs/SPOPS/SPOPS/DBI/Sybase.pm,v 1.13 2000/10/27 04:05:45 cwinters Exp $
 
 use strict;
 
 @SPOPS::DBI::Sybase::ISA     = ();
-$SPOPS::DBI::Sybase::VERSION = sprintf("%d.%02d", q$Revision: 1.10 $ =~ /(\d+)\.(\d+)/);
+$SPOPS::DBI::Sybase::VERSION = sprintf("%d.%02d", q$Revision: 1.13 $ =~ /(\d+)\.(\d+)/);
 
 use constant DEBUG => 0;
 
@@ -45,6 +45,8 @@ sub post_fetch_id {
 
 1;
 
+__END__
+
 =pod
 
 =head1 NAME
@@ -108,6 +110,7 @@ it under the same terms as Perl itself.
 
 =head1 AUTHORS
 
- Chris Winters (cwinters@intes.net)
+Chris Winters  <cwinters@intes.net>
+
 
 =cut
